# CHANGELOG

<!-- version list -->

## v1.1.0 (2026-02-11)

### Chores

- Add to tests ([#3](https://github.com/BrightNight-Energy/turbodiff/pull/3),
  [`8d054e0`](https://github.com/BrightNight-Energy/turbodiff/commit/8d054e0a3ea8d6d286f2570478d8237d66e84d75))

- Fix to release branch protections ([#5](https://github.com/BrightNight-Energy/turbodiff/pull/5),
  [`d490890`](https://github.com/BrightNight-Energy/turbodiff/commit/d490890a1397c338cbd3e9e57bab188ae3fd5ff3))

### Features

- Add limited support for numpy ([#4](https://github.com/BrightNight-Energy/turbodiff/pull/4),
  [`4918e80`](https://github.com/BrightNight-Energy/turbodiff/commit/4918e8089f85ed44e38e6c44cf439fca0e2904c2))


## v1.0.0 (2026-02-11)

- Initial Release
